package navigation

import "github.com/vugu/vugu"

type Sidebar struct {
	AttrMap vugu.AttrMap

	MenuEntries   vugu.Builder `vugu:"data"` // Menu content at the top. Either embedded into the sidebar or at the top edge.
	Entries       vugu.Builder `vugu:"data"` // Main content of the sidebar.
	BottomEntries vugu.Builder `vugu:"data"` // Static bottom part of the sidebar.
	Body          vugu.Builder `vugu:"data"` // The body contains the content that is right to or behind the sidebar.

	Minimized       bool `vugu:"data"` // If true, the sidebar is reduced to icons.
	sidebarClasses  string
	showBodyOverlay bool
}

func (c *Sidebar) Init(ctx vugu.InitCtx) {
	c.Minimized = true // Sidebar defaults to minimized.
}

func (c *Sidebar) Compute(ctx vugu.ComputeCtx) {
	if c.Minimized {
		c.sidebarClasses = "d3c-1633357633-sidebar-minimized d3c-button-only-icon"
		c.showBodyOverlay = false
	} else {
		c.sidebarClasses = ""
		c.showBodyOverlay = true
	}
}

func (c *Sidebar) handleMenuButton(event vugu.DOMEvent) {
	c.Minimized = !c.Minimized
}

func (c *Sidebar) handleOverlayClick(event vugu.DOMEvent) {
	c.Minimized = true
}
